@@ -32,4 +32,11 @@ new_category.Delete()
 del entry.entry_category
 print entry.entry_category
 
+entry
+entry.author
+entry.author.ref
+entry.author.ref.id
+entry in entry.author.ref.blog_entry_author
+
+
 db.Close()
